# Define libsuffix, minimum libyui-devel version
# and so-version of libyui.
%global libsuffix yui
%global libname lib%{libsuffix}
%global devel_min_ver 3.0.4
%global major_so_ver 7

# Setup _pkgdocdir if not defined already.
%{!?_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}-%{version}}

# CMake-builds go out-of-tree.
%global _cmake_build_subdir build-%{?_arch}%{?dist}

Name:			%{libname}-ncurses
Version:		2.47.2
Release:		1%{?dist}
Summary:		Character Based User Interface for %{libname}

License:		LGPLv2 or LGPLv3
URL:			https://github.com/%{libname}/%{name}
Source0:		%{url}/archive/%{name}/master/%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:		boost-devel
BuildRequires:		cmake				>= 2.8
BuildRequires:		%{libname}-devel		>= %{devel_min_ver}
BuildRequires:		ncurses-devel

Provides:		%{libsuffix}-ui%{?_isa}		== %{major_so_ver}

%description
This package contains the character based (ncurses) user interface
component for %{libname}.


%package devel
Summary:		Files needed for developing with %{name}

Requires:		%{libname}-devel%{?_isa}	>= %{devel_min_ver}
Requires:		%{name}%{?_isa}			== %{version}-%{release}
Requires:		ncurses-devel%{?_isa}

%if 0%{?fedora} && 0%{?fedora} <= 22
Obsoletes:		%{name}-devel-common		<= %{version}-%{release}
%endif #0%{?fedora} && 0%{?fedora} <= 22

%description devel
%{libname} can be used independently of YaST for generic (C++)
applications and has very few dependencies.

You do NOT need this package for developing with %{libname}.
Using %{libname}-devel is sufficient for such purpose.  This
package is only needed when you want to develop an extension
for %{name} which is not covered within the UI-plugin.


%package doc
Summary:		Documentation files for %{name}
BuildArch:		noarch

BuildRequires:		doxygen
BuildRequires:		graphviz
BuildRequires:		hardlink

%description doc
This package includes the developer's documentation as HTML
for %{name}.


%prep
%setup -qn %{name}-%{name}-master-%{version}
./bootstrap.sh


%build
%{__mkdir} -p %{_cmake_build_subdir}
pushd %{_cmake_build_subdir}
%cmake							\
	-DYPREFIX=%{_prefix}				\
	-DLIB_DIR=%{_libdir}				\
	-DCMAKE_BUILD_TYPE=RELEASE			\
	-DRESPECT_FLAGS=ON				\
	..

%{__make} %{?_smp_mflags}
%{__make} %{?_smp_mflags} docs
popd


%install
pushd %{_cmake_build_subdir}
%{__mkdir} -p	%{buildroot}%{_libdir}/%{libsuffix}	\
		%{buildroot}%{_datadir}/%{name}/theme

%make_install

# Delete obsolete files.
%{__rm} -rf	%{buildroot}%{_defaultdocdir}		\
		doc/html/*.m*

# Hard-link documentation.
%{_sbindir}/hardlink -cv doc/html

# Install documentation.
%{__mkdir} -p	%{buildroot}%{?_pkgdocdir}
%{__cp} -a	../ChangeLog ../COPYING* doc/html/	\
		%{buildroot}%{?_pkgdocdir}
popd


%files
%doc %dir %{?_pkgdocdir}
%doc %{?_pkgdocdir}/COPYING*
%{_bindir}/libyui-terminal
%{_libdir}/%{libsuffix}/%{name}.so.%{major_so_ver}*

%files devel
%doc %{?_pkgdocdir}/ChangeLog
%{_datadir}/%{libname}/*
%{_includedir}/%{libsuffix}/*
%{_libdir}/%{libsuffix}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake

%files doc
%doc %{?_pkgdocdir}


%changelog
* Thu Aug 27 2015 Björn Esser <bjoern.esser@gmail.com> - 2.47.2-1
- new upstream release
- added %%{_bindir}/libyui-terminal

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.7-6
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 04 2015 Kalev Lember <kalevlember@gmail.com> - 2.46.7-4
- Rebuilt for GCC 5 C++11 ABI change

* Mon Feb 02 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.7-3
- rebuilt for libyui-3.1.5, again

* Mon Feb 02 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.7-2
- Rebuild for boost 1.57.0

* Tue Jan 20 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.7-1
- new upstream release (#1183541)
- rebuilt for libyui-3.1.5
- keep doc-files in unfied %%{_pkgdocdir}
- small improvements to spec-file

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat May 24 2014 Björn Esser <bjoern.esser@gmail.com> - 2.46.4-2
- no need to provide `%%{name}-devel-common`

* Fri May 23 2014 Björn Esser <bjoern.esser@gmail.com> - 2.46.4-1
- new upstream release

* Fri May 23 2014 Björn Esser <bjoern.esser@gmail.com> - 2.44.1-3
- Rebuild for boost 1.55.0

* Tue Mar 18 2014 Björn Esser <bjoern.esser@gmail.com> - 2.44.1-2
- rebuilt for libyui-3.0.13
- remove build of pdf-autodocs
- remove the devel-common subpkg
- minor improvents on spec

* Fri Aug 30 2013 Björn Esser <bjoern.esser@gmail.com> - 2.44.1-1
- new upstream version
- restructured spec to match with libyui

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.43.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu May 16 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.9-3
- changed Provides: `yui_ui =` from `version` to `major_so_ver`
- install lib*.so.`major_so_ver`* in main-pkg not lib*.so.*
- add `-DRESPECT_FLAGS=ON`, will be honored by libyui <= 3.0.5
- removed macros from changelog

* Wed May 15 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.9-2
- -devel pkg should have Requires: ncurses-devel instead of
  Requires: ncurses

* Wed May 15 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.9-1
- new upstream version
- adjusted libyui-devel min-version
- added needed bootstrap to prep

* Wed May 15 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.8-2
- fixup as suggested in https://bugzilla.redhat.com/show_bug.cgi?id=960199#c3
- exchanged {parname} with {libname}

* Mon May 13 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.8-1
- Initial RPM release.
